+++ title = "Table caption" tags = ["table", "caption"] draft = false +++ The caption can contain be emphasized using the usual markup characters too.
Table 1: Awesome table
| h1 | h2 | h3 | |-----|-----|-----| | abc | def | ghi | Some text.
Table 2: Another awesome table with a link
| h1 | h2 | h3 | |-----|-----|-----| | jkl | mno | pqr | Some more text.
Table 3: Third table — Caption with em-dash – and – en-dash
| h1 | h2 | h3 | |-----|-----|----| | stu | vwx | yz |